@@ -317,7 +317,7 @@ sum_runtime <- function(model, software) {
   if (software == 'nonmem') {
     x <- model %>% 
       dplyr::filter(.$subroutine == 'lst') %>% 
-      dplyr::filter(stringr::str_detect(.$code, stringr::fixed('Elapsed estimation time')))
+      dplyr::filter(stringr::str_detect(.$code, 'Elapsed estimation\\s+time'))
     
     if (nrow(x) == 0) return(sum_tpl('runtime', 'na'))
     
@@ -336,7 +336,7 @@ sum_covtime <- function(model, software) {
   if (software == 'nonmem') {
     x <- model %>% 
       dplyr::filter(.$subroutine == 'lst') %>% 
-      dplyr::filter(stringr::str_detect(.$code, stringr::fixed('Elapsed covariance time')))
+      dplyr::filter(stringr::str_detect(.$code, 'Elapsed covariance\\s+time in seconds:\\s+\\d'))
     
     if (nrow(x) == 0) return(sum_tpl('covtime', 'na'))
     
@@ -506,12 +506,12 @@ sum_method <- function(model, software) {
   if (software == 'nonmem') {
     x <- model %>% 
       dplyr::filter(.$subroutine %in% c('sim', 'est')) %>% 
-      dplyr::filter(stringr::str_detect(.$code, 'METHOD|NSUB'))
+      dplyr::filter(stringr::str_detect(.$code, 'METH|NSUB'))
     
     if (nrow(x) == 0) return(sum_tpl('method', 'na'))
     
     x %>% 
-      dplyr::mutate(value = stringr::str_match(.$code, 'METHOD\\s*=\\s*([^\\s]+)')[, 2],
+      dplyr::mutate(value = stringr::str_match(.$code, 'METH[OD]*\\s*=\\s*([^\\s]+)')[, 2],
                     inter = stringr::str_detect(.$code, '\\sINTER'),
                     lapl  = stringr::str_detect(.$code, '\\sLAPLA'),
                     like  = stringr::str_detect(.$code, '\\sLIKE')) %>% 
